==> spip_4.0.4.orig.tar.xz: plugins-dist/medias/lib/mejs/lang/ja.js <==
'use strict';/*!
 * This is a `i18n` language object.
 *
 * Japanese
 *
 * @author
 *   Jalios (Twitter: @Jalios)
 *   Sascha 'SoftCreatR' Greuel
 *
 * @see core/i18n.js
 */
(function (exports) {
	if (exports.ja === undefined) {
		exports.ja = {
			'mejs.plural-form': 0,			
			'mejs.download-file': 'ファイルをダウンロードする',			
			'mejs.install-flash': 'Flash Playerが有効またはインストールされていないブラウザを使用しています。Flash Playerプラグインをオンにするか,https://get.adobe.com/flashplayer/から最新バージョンをダウンロードしてください。',			
			'mejs.fullscreen': '全画面',			
			'mejs.play': '再生',
			'mejs.pause': '一時停止',			
			'mejs.time-slider': 'タイムスライダー',
			'mejs.time-help-text': '1秒進めるには左/右矢印をキーを,10秒進めるには上/下矢印を使います。',
			'mejs.live-broadcast': 'ライブブロードキャスト',			
			'mejs.volume-help-text': '音量を上げたり下げたりするには,上/下矢印を使います。',
			'mejs.unmute': 'ミュートを解除',
			'mejs.mute': 'ミュート',
			'mejs.volume-slider': '音量スライダー',			
			'mejs.video-player': 'ビデオプレーヤー',
			'mejs.audio-player': 'オーディオプレーヤー',			
			'mejs.captions-subtitles': 'キャプション/字幕',
			'mejs.captions-chapters': '章',
			'mejs.none': 'なし',
			'mejs.afrikaans': 'アフリカーンス語',
			'mejs.albanian': 'アルバニア語',
			'mejs.arabic': 'アラビア語',
			'mejs.belarusian': 'ベラルーシ語',
			'mejs.bulgarian': 'ブルガリア語',
			'mejs.catalan': 'カタロニア語',
			'mejs.chinese': '中国語',
			'mejs.chinese-simplified': '中国語（簡体字）',
			'mejs.chinese-traditional': '中国語（繁体字）',
			'mejs.croatian': 'クロアチア語',
			'mejs.czech': 'チェコ語',
			'mejs.danish': 'デンマーク語',
			'mejs.dutch': 'オランダの',
			'mejs.english': '英語',
			'mejs.estonian': 'エストニア語',
			'mejs.filipino': 'フィリピン人',
			'mejs.finnish': 'フィンランド語',
			'mejs.french': 'フランス語',
			'mejs.galician': 'ガリシア人',
			'mejs.german': 'ドイツ語',
			'mejs.greek': 'ギリシャ語',
			'mejs.haitian-creole': 'ハイチクレオール',
			'mejs.hebrew': 'ヘブライ語',
			'mejs.hindi': 'ヒンディー語',
			'mejs.hungarian': 'ハンガリー語',
			'mejs.icelandic': 'アイスランド語',
			'mejs.indonesian': 'インドネシア語',
			'mejs.irish': 'アイルランド',
			'mejs.italian': 'イタリア語',
			'mejs.japanese': '日本語',
			'mejs.korean': '韓国語',
			'mejs.latvian': 'ラトビア語',
			'mejs.lithuanian': 'リトアニア語',
			'mejs.macedonian': 'マケドニアの',
			'mejs.malay': 'マレー語',
			'mejs.maltese': 'マルタ',
			'mejs.norwegian': 'ノルウェー語',
			'mejs.persian': 'ペルシア語',
			'mejs.polish': 'ポーランド語',
			'mejs.portuguese': 'ポルトガル語',
			'mejs.romanian': 'ルーマニア語',
			'mejs.russian': 'ロシア語',
			'mejs.serbian': 'セルビア語',
			'mejs.slovak': 'スロバキア語',
			'mejs.slovenian': 'スロベニア語',
			'mejs.spanish': 'スペイン語',
			'mejs.swahili': 'スワヒリ語',
			'mejs.swedish': 'スウェーデン語',
			'mejs.tagalog': 'タガログ',
			'mejs.thai': 'タイ',
			'mejs.turkish': 'トルコ語',
			'mejs.ukrainian': 'ウクライナ語',
			'mejs.vietnamese': 'ベトナム語',
			'mejs.welsh': 'ウェールズ',
			'mejs.yiddish': 'イディッシュ'
		};
	}
})(mejs.i18n);

==> spip_4.3.8+dfsg.orig.tar.xz: plugins-dist/medias/lib/mejs/lang/ja.js <==
/*!
 * This is a `i18n` language object.
 *
 * Japanese
 *
 * @author
 *   Jalios (Twitter: @Jalios)
 *   Sascha 'SoftCreatR' Greuel
 *
 * @see core/i18n.js
 */
(function (exports) {
    'use strict';	if (exports.ja === undefined) {
		exports.ja = {
			'mejs.plural-form': 0,			
			'mejs.download-file': 'ファイルをダウンロードする',			
			'mejs.fullscreen': '全画面',			
			'mejs.play': '再生',
			'mejs.pause': '一時停止',			
			'mejs.time-slider': 'タイムスライダー',
			'mejs.time-help-text': '1秒進めるには左/右矢印をキーを,10秒進めるには上/下矢印を使います。',
			'mejs.live-broadcast': 'ライブブロードキャスト',			
			'mejs.volume-help-text': '音量を上げたり下げたりするには,上/下矢印を使います。',
			'mejs.unmute': 'ミュートを解除',
			'mejs.mute': 'ミュート',
			'mejs.volume-slider': '音量スライダー',			
			'mejs.video-player': 'ビデオプレーヤー',
			'mejs.audio-player': 'オーディオプレーヤー',			
			'mejs.captions-subtitles': 'キャプション/字幕',
			'mejs.captions-chapters': '章',
			'mejs.none': 'なし',
			'mejs.afrikaans': 'アフリカーンス語',
			'mejs.albanian': 'アルバニア語',
			'mejs.arabic': 'アラビア語',
			'mejs.belarusian': 'ベラルーシ語',
			'mejs.bulgarian': 'ブルガリア語',
			'mejs.catalan': 'カタロニア語',
			'mejs.chinese': '中国語',
			'mejs.chinese-simplified': '中国語（簡体字）',
			'mejs.chinese-traditional': '中国語（繁体字）',
			'mejs.croatian': 'クロアチア語',
			'mejs.czech': 'チェコ語',
			'mejs.danish': 'デンマーク語',
			'mejs.dutch': 'オランダの',
			'mejs.english': '英語',
			'mejs.estonian': 'エストニア語',
			'mejs.filipino': 'フィリピン人',
			'mejs.finnish': 'フィンランド語',
			'mejs.french': 'フランス語',
			'mejs.galician': 'ガリシア人',
			'mejs.german': 'ドイツ語',
			'mejs.greek': 'ギリシャ語',
			'mejs.haitian-creole': 'ハイチクレオール',
			'mejs.hebrew': 'ヘブライ語',
			'mejs.hindi': 'ヒンディー語',
			'mejs.hungarian': 'ハンガリー語',
			'mejs.icelandic': 'アイスランド語',
			'mejs.indonesian': 'インドネシア語',
			'mejs.irish': 'アイルランド',
			'mejs.italian': 'イタリア語',
			'mejs.japanese': '日本語',
			'mejs.korean': '韓国語',
			'mejs.latvian': 'ラトビア語',
			'mejs.lithuanian': 'リトアニア語',
			'mejs.macedonian': 'マケドニアの',
			'mejs.malay': 'マレー語',
			'mejs.maltese': 'マルタ',
			'mejs.norwegian': 'ノルウェー語',
			'mejs.persian': 'ペルシア語',
			'mejs.polish': 'ポーランド語',
			'mejs.portuguese': 'ポルトガル語',
			'mejs.romanian': 'ルーマニア語',
			'mejs.russian': 'ロシア語',
			'mejs.serbian': 'セルビア語',
			'mejs.slovak': 'スロバキア語',
			'mejs.slovenian': 'スロベニア語',
			'mejs.spanish': 'スペイン語',
			'mejs.swahili': 'スワヒリ語',
			'mejs.swedish': 'スウェーデン語',
			'mejs.tagalog': 'タガログ',
			'mejs.thai': 'タイ',
			'mejs.turkish': 'トルコ語',
			'mejs.ukrainian': 'ウクライナ語',
			'mejs.vietnamese': 'ベトナム語',
			'mejs.welsh': 'ウェールズ',
			'mejs.yiddish': 'イディッシュ'
		};
	}
})(mejs.i18n);
